package com.logicbig.example;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import java.util.List;

public class ExampleMain2 {

    public static void main(String[] args) {
        EntityManagerFactory emf =
                Persistence.createEntityManagerFactory("example-unit");
        try {
            persistEntity(emf);
            loadEntities(emf);
        } finally {
            emf.close();
        }
    }

    private static void persistEntity(EntityManagerFactory emf) {
        System.out.println("-- Persisting Employee entity --");
        EntityManager em = emf.createEntityManager();

        Employee employee = new Employee();
        employee.setName("Maria Dorsey");
        employee.setDepartment("Admin");

        em.getTransaction().begin();
        logPersistentStatus("before persisting", employee, em);
        em.persist(employee);
        logPersistentStatus("after persisting", employee, em);
        System.out.println("-- rolling back --");
        em.getTransaction().rollback();

        System.out.println("-- persisting second employee --");
        Employee employee2 = new Employee();
        employee2.setName("Tim Don");
        employee2.setDepartment("Sales");

        em.getTransaction().begin();
        logPersistentStatus("before persisting", employee2, em);
        em.persist(employee2);
        logPersistentStatus("after persisting", employee2, em);
        em.getTransaction().commit();
        em.close();
    }

    private static void logPersistentStatus(String msg, Employee employee, EntityManager em) {
        System.out.printf("-- %s --%n", msg);
        System.out.println("employee#id: " + employee.getId());
        System.out.println("EntityManager#contains(): " + em.contains(employee));
    }

    private static void loadEntities(EntityManagerFactory emf) {
        System.out.println("-- Loading Employee --");
        EntityManager em = emf.createEntityManager();
        List<Employee> employees = em.createQuery("Select t from Employee t")
                                     .getResultList();
        employees.forEach(ExampleMain2::printObject);
        em.close();
    }

    private static void printObject(Object obj) {
        System.out.println("Object: " + obj);
    }
}